###############################################################################
################## SCRIPT FOR LOADING ALL SCORECARD FUNCTIONS #################
###############################################################################

##### Script requires module Phantomjs, currently loaded in WS
##### If using Nord3, the module needs to be loaded before running the code
##### To load Phantomjs in Nord3: module load Phantomjs

##### To open R in Nord3: 
#  module load R/4.1.2-foss-2019b
#  module load OpenMPI/4.0.5-GCC-8.3.0-nord3-v2
#  R

## Cleaning
rm(list = ls()); gc()

### Set the working directory containing the scripts
setwd("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/")


##### Load libraries ######
library(ncdf4) ## to load netCDF files
library(formattable) ## to plot horizontal color bars
library(kableExtra) ## to print data in formatted tables
library(stringr) ## for manipulating capitals in the figure title
library(s2dv) ## for function ColorBar() ## previously s2dverification
library(abind) ## for function abind()
library(data.table) ## for function %like%
library(ClimProjDiags) ## for WeightedMean function
library(yaml) ## to read yaml files


## Input path where the data files are located
input.path <- '/esarchive/scratch/nmilders/scorecards_data/input_data'

## Location where the scorecards images are saved
fileout <- '/esarchive/scratch/nmilders/scorecards_data/saved_results'

## Load data files
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_1_load_metrics.R")
#loaded_metrics <- SC_load_metrics(recipe)
loaded_metrics <- SC_load_metrics(system = c('ecmwfs5', 'dwds2'),
                                  reference = 'era5',
                                  var = 'prlr',
                                  start.year = 1993,
                                  end.year = 2016,
                                  metrics =  c('mean_bias', 'enscorr', 'rpss', 'crpss', 'enssprerr'),
                                  start.months = sprintf("%02d", 1:12),
                                  forecast.months = 1:6,
                                  input.path = input.path)



## Calculate weighted mean of spatial aggregation
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_2_spatial_aggregation.R")
aggregated_metrics <- SC_spatial_aggregation(loaded_metrics,
                                             metrics = c('mean_bias', 'enscorr', 'rpss', 'crpss', 'enssprerr'), 
                                             regions = list('Tropics' = c(lon.min = 0, lon.max = 360, lat.min = -30, lat.max = 30),
                                                            'Extra-tropical NH' = c(lon.min = -0, lon.max = 360, lat.min = 30, lat.max = 90),
                                                            'Extra-tropical SH' = c(lon.min = 0, lon.max = 360, lat.min = -30, lat.max = -90)),
                                             
                                             ncores = 4)

## Calculate skill score from aggregated score
## Only used for calculating skill scores (RPSS/CRPSS) from their respective scores (RPS/CRPS)
# source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_2.5_skill_score_calculation.R")
# skill_scores <- SC_skill_scores(data,
#                                 metrics, 
#                                 ncores)
  

## Create simple scorecard tables 
## (one system only)
## Metrics input must be in the same order as function SC_spatial_aggregation
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_3_create_scorecard_simple.R")
scorecard_simple <- SC_create_table_simple(input_data = aggregated_metrics,
                                           system = c('ecmwfs5', 'dwds2'),
                                           reference = 'era5',
                                           var = 'prlr', 
                                           start.year = 1993,
                                           end.year = 2016,
                                           start.months = 1:12,
                                           forecast.months = 1:6,
                                           region.names = c('Tropics', 'Extra-tropical NH', 'Extra-tropical SH'),
                                           metrics = c('mean_bias', 'enscorr', 'rpss','crpss', 'enssprerr'),
                                           fileout = fileout)


## Create multi system/ reference scorecard tables 
## (multiple systems with one reference or one system with multiple references)
## Metrics input must be in the same order as function SC_spatial_aggregation
## ISSUE with system names in plots - Needs to be fixed!
source("/esarchive/scratch/nmilders/gitlab/git_clones/s2s-suite/modules/Scorecards/SC_4_create_scorecard_multi.R")
scorecard_multi <- SC_create_table_multi(input_data = aggregated_metrics,
                                           system = c('ecmwfs5','dwds2'),
                                           reference = 'era5',
                                           var = 'prlr', 
                                           start.year = 1993,
                                           end.year = 2016,
                                           start.months = 1:12,
                                           forecast.months = 1:6,
                                           region.names = c('Tropics', 'Extra-tropical NH', 'Extra-tropical SH'),
                                           metrics = c('mean_bias', 'enscorr', 'rpss','crpss', 'enssprerr'),
                                           fileout = fileout)



